@@ -1,11 +1,11 @@
 /* Hierarchical argument parsing, layered over getopt
-   Copyright (C) 1995-2021 Free Software Foundation, Inc.
+   Copyright (C) 1995-2025 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Written by Miles Bader <miles@gnu.ai.mit.edu>.
 
    This file is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as
-   published by the Free Software Foundation; either version 3 of the
+   published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.
 
    This file is distributed in the hope that it will be useful,
@@ -21,7 +21,6 @@
 #endif
 
 #include <alloca.h>
-#include <stdalign.h>
 #include <stddef.h>
 #include <stdlib.h>
 #include <string.h>
@@ -78,13 +77,13 @@ static volatile int _argp_hang;
 
 static const struct argp_option argp_default_options[] =
 {
-  {"help",        '?',          0, 0,  N_("give this help list"), -1},
-  {"usage",       OPT_USAGE,    0, 0,  N_("give a short usage message"), 0},
+  {"help",        '?',          NULL, 0,  N_("give this help list"), -1},
+  {"usage",       OPT_USAGE,    NULL, 0,  N_("give a short usage message"), 0},
   {"program-name",OPT_PROGNAME, N_("NAME"), OPTION_HIDDEN,
    N_("set the program name"), 0},
   {"HANG",        OPT_HANG,    N_("SECS"), OPTION_ARG_OPTIONAL | OPTION_HIDDEN,
    N_("hang for SECS seconds (default 3600)"), 0},
-  {NULL, 0, 0, 0, NULL, 0}
+  {NULL, 0, NULL, 0, NULL, 0}
 };
 
 static error_t
@@ -140,8 +139,8 @@ static const struct argp argp_default_argp =
 
 static const struct argp_option argp_version_options[] =
 {
-  {"version",     'V',          0, 0,  N_("print program version"), -1},
-  {NULL, 0, 0, 0, NULL, 0}
+  {"version",     'V',          NULL, 0,  N_("print program version"), -1},
+  {NULL, 0, NULL, 0, NULL, 0}
 };
 
 static error_t
@@ -249,7 +248,7 @@ struct parser
   /* LONG_OPTS is the array of getop long option structures for the union of
      all the groups of options.  */
   struct option *long_opts;
-  /* OPT_DATA is the getopt data used for the re-entrant getopt.  */
+  /* OPT_DATA is the getopt data used for the reentrant getopt.  */
   struct _getopt_data opt_data;
 
   /* States of the various parsing groups.  */
@@ -333,7 +332,7 @@ convert_options (const struct argp *argp,
                           ? optional_argument
                           : required_argument)
                        : no_argument);
-                    cvt->long_end->flag = 0;
+                    cvt->long_end->flag = NULL;
                     /* we add a disambiguating code to all the user's
                        values (which is removed before we actually call
                        the function to parse the value); this means that
@@ -356,9 +355,9 @@ convert_options (const struct argp *argp,
       group->args_processed = 0;
       group->parent = parent;
       group->parent_index = parent_index;
-      group->input = 0;
-      group->hook = 0;
-      group->child_inputs = 0;
+      group->input = NULL;
+      group->hook = NULL;
+      group->child_inputs = NULL;
 
       if (children)
         /* Assign GROUP's CHILD_INPUTS field some space from
@@ -374,7 +373,7 @@ convert_options (const struct argp *argp,
       parent = group++;
     }
   else
-    parent = 0;
+    parent = NULL;
 
   if (children)
     {
@@ -409,7 +408,7 @@ parser_convert (struct parser *parser, const struct argp *argp, int flags)
   parser->argp = argp;
 
   if (argp)
-    parser->egroup = convert_options (argp, 0, 0, parser->groups, &cvt);
+    parser->egroup = convert_options (argp, NULL, 0, parser->groups, &cvt);
   else
     parser->egroup = parser->groups; /* No parsers at all! */
 }
@@ -538,7 +537,7 @@ parser_init (struct parser *parser, const struct argp *argp,
            makes very simple wrapper argps more convenient).  */
         group->child_inputs[0] = group->input;
 
-      err = group_parse (group, &parser->state, ARGP_KEY_INIT, 0);
+      err = group_parse (group, &parser->state, ARGP_KEY_INIT, NULL);
     }
   if (err == EBADKEY)
     err = 0;                    /* Some parser didn't understand.  */
@@ -587,11 +586,11 @@ parser_finalize (struct parser *parser,
                group < parser->egroup && (!err || err==EBADKEY);
                group++)
             if (group->args_processed == 0)
-              err = group_parse (group, &parser->state, ARGP_KEY_NO_ARGS, 0);
+              err = group_parse (group, &parser->state, ARGP_KEY_NO_ARGS, NULL);
           for (group = parser->egroup - 1;
                group >= parser->groups && (!err || err==EBADKEY);
                group--)
-            err = group_parse (group, &parser->state, ARGP_KEY_END, 0);
+            err = group_parse (group, &parser->state, ARGP_KEY_END, NULL);
 
           if (err == EBADKEY)
             err = 0;            /* Some parser didn't understand.  */
@@ -630,7 +629,7 @@ parser_finalize (struct parser *parser,
 
       /* Since we didn't exit, give each parser an error indication.  */
       for (group = parser->groups; group < parser->egroup; group++)
-        group_parse (group, &parser->state, ARGP_KEY_ERROR, 0);
+        group_parse (group, &parser->state, ARGP_KEY_ERROR, NULL);
     }
   else
     /* Notify parsers of success, and propagate back values from parsers.  */
@@ -641,14 +640,14 @@ parser_finalize (struct parser *parser,
       for (group = parser->egroup - 1
            ; group >= parser->groups && (!err || err == EBADKEY)
            ; group--)
-        err = group_parse (group, &parser->state, ARGP_KEY_SUCCESS, 0);
+        err = group_parse (group, &parser->state, ARGP_KEY_SUCCESS, NULL);
       if (err == EBADKEY)
         err = 0;                /* Some parser didn't understand.  */
     }
 
   /* Call parsers once more, to do any final cleanup.  Errors are ignored.  */
   for (group = parser->egroup - 1; group >= parser->groups; group--)
-    group_parse (group, &parser->state, ARGP_KEY_FINI, 0);
+    group_parse (group, &parser->state, ARGP_KEY_FINI, NULL);
 
   if (err == EBADKEY)
     err = EINVAL;
@@ -687,7 +686,7 @@ parser_parse_arg (struct parser *parser, char *val)
         {
           parser->state.next--; /* For ARGP_KEY_ARGS, put back the arg.  */
           key = ARGP_KEY_ARGS;
-          err = group_parse (group, &parser->state, key, 0);
+          err = group_parse (group, &parser->state, key, NULL);
         }
     }
 
@@ -800,11 +799,11 @@ parser_parse_next (struct parser *parser, int *arg_ebadkey)
       parser->opt_data.optopt = KEY_END;
       if (parser->state.flags & ARGP_LONG_ONLY)
         opt = _getopt_long_only_r (parser->state.argc, parser->state.argv,
-                                   parser->short_opts, parser->long_opts, 0,
+                                   parser->short_opts, parser->long_opts, NULL,
                                    &parser->opt_data);
       else
         opt = _getopt_long_r (parser->state.argc, parser->state.argv,
-                              parser->short_opts, parser->long_opts, 0,
+                              parser->short_opts, parser->long_opts, NULL,
                               &parser->opt_data);
       /* And see what getopt did.  */
       parser->state.next = parser->opt_data.optind;
@@ -913,7 +912,7 @@ __argp_parse (const struct argp *argp, int argc, char **argv, unsigned flags,
       (child++)->argp = &argp_default_argp;
       if (argp_program_version || argp_program_version_hook)
         (child++)->argp = &argp_version_argp;
-      child->argp = 0;
+      child->argp = NULL;
 
       argp = top_argp;
     }
@@ -950,7 +949,7 @@ __argp_input (const struct argp *argp, const struct argp_state *state)
           return group->input;
     }
 
-  return 0;
+  return NULL;
 }
 #ifdef weak_alias
 weak_alias (__argp_input, _argp_input)
