@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1993-2023 Free Software Foundation, Inc.
+  Copyright (C) 1993-2025 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -112,7 +112,7 @@ static struct argp_option argp_options[] = {
   {"debug", 'D', "LEVEL", OPTION_ARG_OPTIONAL,
    "set debugging level", GRID},
   {"exec-login", 'E', "STRING", 0,
-   "set program to be executed instead of " PATH_LOGIN, GRID},
+   "set program to be executed instead of standard login(1)", GRID},
   {"no-hostinfo", 'h', NULL, 0,
    "do not print host information before login has been completed", GRID},
   {"linemode", 'l', "MODE", OPTION_ARG_OPTIONAL,
@@ -618,7 +618,7 @@ telnetd_run (void)
   for (;;)
     {
       fd_set ibits, obits, xbits;
-      register int c;
+      int c;
 
       if (net_input_level () < 0 && pty_input_level () < 0)
 	break;
